[![unittests](https://github.com/haddocking/prodigy-cryst/actions/workflows/unittests.yml/badge.svg)](https://github.com/haddocking/prodigy-cryst/actions/workflows/unittests.yml)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/4f129d451ec04c4e9529a6eb28457619)](https://www.codacy.com/gh/haddocking/prodigy-cryst/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=haddocking/prodigy-cryst&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/4f129d451ec04c4e9529a6eb28457619)](https://www.codacy.com/gh/haddocking/prodigy-cryst/dashboard?utm_source=github.com&utm_medium=referral&utm_content=haddocking/prodigy-cryst&utm_campaign=Badge_Coverage)
[![fair-software.eu](https://img.shields.io/badge/fair--software.eu-%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8B%20%20%E2%97%8B%20%20%E2%97%8B-orange)](https://fair-software.eu)

# PRODIGY-cryst

Collection of scripts to predict whether an interface in a protein-protein complex is biological or crystallographic from its atomic coordinates.

## Installation

```bash
> git clone http://github.com/haddocking/prodigy-cryst
> python setup.py install
```

## Usage

```bash
prodigy_cryst <pdb file> [--selection <chain1><chain2>]
```

Type --help to get a list of all the possible options.
